<p align="center">
  <a href="https://github.com/AlexDemure/gadlint">
    <a href="https://ibb.co/Vc0tFPnw"><img src="https://i.ibb.co/rRKmB18d/logo.png" alt="logo" border="0"></a>
  </a>
</p>

<p align="center">
  CLI tool that runs isort, ruff, mypy, and radon with built-in configurations.
</p>

---

### Installation

```
pip install gadlint
```

### Usage

```sh
gadlint .
```
